# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240102

from __future__ import absolute_import

from .additional_patches import AdditionalPatches
from .aggregated_vulnerability_collection import AggregatedVulnerabilityCollection
from .aggregated_vulnerability_summary import AggregatedVulnerabilitySummary
from .child_pdb import ChildPdb
from .create_vulnerability_scan_details import CreateVulnerabilityScanDetails
from .databases_summary import DatabasesSummary
from .dblm_patch_management import DblmPatchManagement
from .dblm_vulnerability import DblmVulnerability
from .fpp_server import FppServer
from .host_info import HostInfo
from .image_details import ImageDetails
from .images_patch_recommendation_summary import ImagesPatchRecommendationSummary
from .metric_error import MetricError
from .notification_collection import NotificationCollection
from .notification_summary import NotificationSummary
from .patch_activity_details import PatchActivityDetails
from .patch_compliance_details import PatchComplianceDetails
from .patch_databases_collection import PatchDatabasesCollection
from .patch_operations_summary import PatchOperationsSummary
from .patch_recommendation_summary import PatchRecommendationSummary
from .patch_recommendations_details_summary import PatchRecommendationsDetailsSummary
from .resource_info import ResourceInfo
from .resource_summary import ResourceSummary
from .resources_patch_compliance_summary import ResourcesPatchComplianceSummary
from .vulnerabilities_summary import VulnerabilitiesSummary
from .vulnerability_collection import VulnerabilityCollection
from .vulnerability_resource_collection import VulnerabilityResourceCollection
from .vulnerability_resource_summary import VulnerabilityResourceSummary
from .vulnerability_scan import VulnerabilityScan
from .vulnerability_scan_collection import VulnerabilityScanCollection
from .vulnerability_scan_summary import VulnerabilityScanSummary
from .vulnerability_summary import VulnerabilitySummary
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for dblm services.
dblm_type_mapping = {
    "AdditionalPatches": AdditionalPatches,
    "AggregatedVulnerabilityCollection": AggregatedVulnerabilityCollection,
    "AggregatedVulnerabilitySummary": AggregatedVulnerabilitySummary,
    "ChildPdb": ChildPdb,
    "CreateVulnerabilityScanDetails": CreateVulnerabilityScanDetails,
    "DatabasesSummary": DatabasesSummary,
    "DblmPatchManagement": DblmPatchManagement,
    "DblmVulnerability": DblmVulnerability,
    "FppServer": FppServer,
    "HostInfo": HostInfo,
    "ImageDetails": ImageDetails,
    "ImagesPatchRecommendationSummary": ImagesPatchRecommendationSummary,
    "MetricError": MetricError,
    "NotificationCollection": NotificationCollection,
    "NotificationSummary": NotificationSummary,
    "PatchActivityDetails": PatchActivityDetails,
    "PatchComplianceDetails": PatchComplianceDetails,
    "PatchDatabasesCollection": PatchDatabasesCollection,
    "PatchOperationsSummary": PatchOperationsSummary,
    "PatchRecommendationSummary": PatchRecommendationSummary,
    "PatchRecommendationsDetailsSummary": PatchRecommendationsDetailsSummary,
    "ResourceInfo": ResourceInfo,
    "ResourceSummary": ResourceSummary,
    "ResourcesPatchComplianceSummary": ResourcesPatchComplianceSummary,
    "VulnerabilitiesSummary": VulnerabilitiesSummary,
    "VulnerabilityCollection": VulnerabilityCollection,
    "VulnerabilityResourceCollection": VulnerabilityResourceCollection,
    "VulnerabilityResourceSummary": VulnerabilityResourceSummary,
    "VulnerabilityScan": VulnerabilityScan,
    "VulnerabilityScanCollection": VulnerabilityScanCollection,
    "VulnerabilityScanSummary": VulnerabilityScanSummary,
    "VulnerabilitySummary": VulnerabilitySummary,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}
